.. rst-class:: detail

RosClient
====================

.. currentmodule:: compas_rrc

.. autoclass:: RosClient

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~RosClient.__init__
        ~RosClient.add_attached_collision_mesh
        ~RosClient.add_collision_mesh
        ~RosClient.append_collision_mesh
        ~RosClient.blocking_call_from_thread
        ~RosClient.call_async_service
        ~RosClient.call_in_thread
        ~RosClient.call_later
        ~RosClient.call_sync_service
        ~RosClient.close
        ~RosClient.connect
        ~RosClient.delete_param
        ~RosClient.emit
        ~RosClient.execute_joint_trajectory
        ~RosClient.follow_configurations
        ~RosClient.follow_joint_trajectory
        ~RosClient.forward_kinematics
        ~RosClient.get_action_servers
        ~RosClient.get_configuration
        ~RosClient.get_message_details
        ~RosClient.get_node_details
        ~RosClient.get_nodes
        ~RosClient.get_param
        ~RosClient.get_params
        ~RosClient.get_planning_scene
        ~RosClient.get_service_request_callback
        ~RosClient.get_service_request_details
        ~RosClient.get_service_response_details
        ~RosClient.get_service_type
        ~RosClient.get_services
        ~RosClient.get_services_for_type
        ~RosClient.get_time
        ~RosClient.get_topic_type
        ~RosClient.get_topics
        ~RosClient.get_topics_for_type
        ~RosClient.inverse_kinematics
        ~RosClient.load_robot
        ~RosClient.off
        ~RosClient.on
        ~RosClient.on_ready
        ~RosClient.plan_cartesian_motion
        ~RosClient.plan_motion
        ~RosClient.remove_attached_collision_mesh
        ~RosClient.remove_collision_mesh
        ~RosClient.reset_planning_scene
        ~RosClient.run
        ~RosClient.run_event_loop
        ~RosClient.run_forever
        ~RosClient.send_on_ready
        ~RosClient.set_param
        ~RosClient.set_status_level
        ~RosClient.terminate
    
    